@@ -5,12 +5,12 @@ This module does not contain docstrings for the wrapped code, check Apple's
 documentation for details on how to use these functions and classes.
 """
 
-import objc
 import sys
-import Foundation
 
+import Foundation
+import objc
 from CryptoTokenKit import _metadata
-from CryptoTokenKit._CryptoTokenKit import *
+from CryptoTokenKit import _CryptoTokenKit
 
 sys.modules["CryptoTokenKit"] = mod = objc.ObjCLazyModule(
     "CryptoTokenKit",
@@ -24,9 +24,8 @@ sys.modules["CryptoTokenKit"] = mod = objc.ObjCLazyModule(
         "__path__": __path__,
         "__loader__": globals().get("__loader__", None),
     },
-    (Foundation,),
+    (_CryptoTokenKit, Foundation),
 )
 
-import sys
 
 del sys.modules["CryptoTokenKit._metadata"]
